@@ -30,10 +30,10 @@ import pyparticles.ogl.draw_particles_ogl as drp
 from OpenGL.GL import *
 from OpenGL.GLUT import *
 from OpenGL.GLU import *
+ 
 
 import time
 
-
 def InitGL( Width , Height , ReSizeFun ):
     """
     Initialize OpenGl 
@@ -57,6 +57,8 @@ def InitGL( Width , Height , ReSizeFun ):
     
     ReSizeFun(Width, Height)
     
+    
+    
     InitLight()
 
 
@@ -120,6 +122,9 @@ def DrawGLScene():
     if DrawGLScene.animation.print_help :
         print_help()
     
+    if DrawGLScene.animation.fps_print :
+        print_fps( DrawGLScene.animation.fps )
+    
     SetPerspective( DrawGLScene.animation )
 
     glPushMatrix()
@@ -203,6 +208,9 @@ def KeyPressed( c , x , y ):
     if c == 't' :
         KeyPressed.animation.trajectory = not KeyPressed.animation.trajectory
         
+    if c == 'f' :
+        KeyPressed.animation.fps_print = not KeyPressed.animation.fps_print        
+        
     if c == 'p' :
         KeyPressed.animation.draw_particles.set_particle_model( model="point" )
         
@@ -219,7 +227,7 @@ def KeyPressed( c , x , y ):
         KeyPressed.animation.light = False
         
     if c == 'v' :
-        KeyPressed.animation.draw_vector_field = not KeyPressed.animation.draw_vector_field
+        KeyPressed.animation.draw_vector_field = ( not KeyPressed.animation.draw_vector_field ) and ( KeyPressed.animation.vector_field != None )
         
         
 
@@ -313,6 +321,9 @@ def print_help():
     y -= 0.05
     glut_print( 0.1 , y , GLUT_BITMAP_9_BY_15 , "v: Toggle vector field " , 1 , 1 , 1 , 1 )
     
+    y -= 0.05
+    glut_print( 0.1 , y , GLUT_BITMAP_9_BY_15 , "f: Toggle FPS " , 1 , 1 , 1 , 1 )
+    
     y -= 0.1    
     glut_print( 0.1 , y , GLUT_BITMAP_9_BY_15 , "h: Toggle help message" , 1 , 1 , 1 , 1 )
     
@@ -328,8 +339,11 @@ def print_measures():
         glut_print( 0.7 , y , GLUT_BITMAP_9_BY_15 , " %s:  %s " % ( na , m ) , 1 , 1 , 1 , 1 )
         y -= 0.05
         
+        
+def print_fps( fps ):
+    glut_print( 0.9 , 0.05 , GLUT_BITMAP_9_BY_15 , "FPS: %.2f" % fps , 1 , 1 , 1 , 1 )
     
-
+        
 def glut_print( x,  y,  font,  text, r,  g , b , a):
         
     blending = False 
@@ -620,21 +634,17 @@ class AnimatedGl( pan.Animation ):
             
         if self.vector_field != None :
             self.vector_field.ogl_init()
-        
+            
         
     def data_stream(self):
         
-        #a = time.time()
-        
         self.pset.log()
         
         self.ode_solver.step()
-        
         self.perform_measurement()
         
-        #b = time.time()
-        #print( "step_time = %f " % (b-a) )
-
+        self.update_fps()
+        
         return self.ode_solver.steps_cnt
         
     
