@@ -22,16 +22,19 @@ import pyparticles.forces.force as fr
 
 class Electrostatic( fr.Force ) :
     r"""
-    Compute the electrostatic force.
-        Note: The real force of an electrodynamic system is given by the **Maxwell equations**! and not from the Culomb law.
+    Compute the electrostatic force using the Culomb law.
         
-        The Culomb law is adapt only for computing a static system of particles, and not for moving particles.
+    ..note::
+     
+        The real forces of an electrodynamic system is given by the **Maxwell equations**! and not from the Culomb law.
+        
+        The Culomb law is adapt for computing forces in a static system of particles and not for moving particles.
         
         But for a very slow movement it should be a good approximation.
         
-        .. math::
+    .. math::
         
-            \vec F = k \, q_1 \, q_2 \, \frac {\vec r_1 - \vec r_2}{\left \| \vec r_1 - \vec r_2 \right \|^3}
+        \vec F = k \, q_1 \, q_2 \, \frac {\vec r_1 - \vec r_2}{\left \| \vec r_1 - \vec r_2 \right \|^3}
     """
     def __init__(self , size , dim=3 , m=None , q=None , Consts=1.0 ):
         
