@@ -15,7 +15,6 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import numpy as np
-import sys
 import scipy.spatial.distance as dist
 
 import pyparticles.forces.force as fr
@@ -31,20 +30,16 @@ class LenardJones( fr.Force ) :
 
         \mathbf{F}(r) = 4 \epsilon \left(12\,{\frac{{\sigma}^{12}}{{r}^{13}}}-6\,{\frac{{\sigma}^{6}}{{r}^{7}}}\right)\hat{\mathbf{r}}
 
+    Constructor:
 
-    Constructor
+    :param    size:        the number of particles in the system
+    :param    dim:         the dimension of the system
+    :param    m:           a vector containig the masses
+    :param    Const:       An indexable object[*] with the two contants
+        
 
-        ==========  =============================================
-        Arguments
-        ==========  =============================================
-        size        the number of particles in the system
-        dim         the dimension of the system
-        m           a vector containig the masses
-        Const       An indexable object[*] with the two contants
-        ==========  =============================================
-
-         [*] Const[0] = :math:`\epsilon`
-             Const[1] = :math:`\sigma`
+    [*] Const[0] = :math:`\epsilon`
+        Const[1] = :math:`\sigma`
 
     """
 
@@ -68,21 +63,17 @@ class LenardJones( fr.Force ) :
         
         
     def set_masses( self , m ):
-       """
-       Set the masses used for computing the forces.
-       """
-       self.__M[:] = m
+        """
+        Set the masses used for computing the forces.
+        """
+        self.__M[:] = m
        
     
     def update_force( self , p_set ):
         """
         Compute the force of the current status of the system and return the accelerations of every particle in a *size by dim* array
         
-            ========= ==================
-            Arguments
-            ========= ==================
-            p_set     Particles set obj.
-            ========= ==================
+        :param    p_set:     Particles set obj.
         """
         
         r =  dist.pdist( p_set.X , 'euclidean' )
