@@ -25,6 +25,8 @@ import matplotlib
 import numpy as np
 
 import pyparticles.pset.particles_set as ps
+import pyparticles.pset.logger as log
+
 import pyparticles.animation.animated_scatter as anim
 
 import pyparticles.animation as pan
@@ -41,8 +43,6 @@ import pyparticles.ode.stormer_verlet_solver as svs
 import matplotlib.animation as animation
 
 
-
-
 import pyparticles.pset.periodic_boundary as pb
 import pyparticles.pset.rebound_boundary as rb
 import pyparticles.forces.const_force as cf
@@ -218,6 +218,19 @@ class MyField( vf.VectorFieldForce ):
 
 
 def my_test() :
+    
+    
+    pset = ps.ParticlesSet( 10 )
+    
+    lo = log.Logger( pset , 10 )
+    
+    for i in range( 105 ) :
+        pset.X[:] =  float(i) 
+        lo.log()
+        
+        print( lo.get_particles_log( 3 ) )
+    
+    exit()
         
     t = tr.Transformations()
     
