@@ -23,6 +23,7 @@ from OpenGL.GL import *
 from OpenGL.GLUT import *
 from OpenGL.GLU import *
 
+
 def charged_particles_color( pset , i ):
     a = 0.4 
     
@@ -33,9 +34,11 @@ def charged_particles_color( pset , i ):
     else :
         return ( a , a , a , 1.0 )
 
+
 def rand_vect_colors( RGBA , pset ):
     RGBA[:] = np.random.rand( pset.size , 4 )
 
+
 def charged_particles_vect_color( RGBA , pset ):
     a = 0.4
     
@@ -48,6 +51,7 @@ def charged_particles_vect_color( RGBA , pset ):
     i, foo = np.where( pset.Q == 0.0 )
     RGBA[ i , : ] = np.array( [ a , a , a , 1.0 ] )
 
+
 class DrawParticlesGL(object):
     
     DRAW_MODEL_LOOP = 0
@@ -77,6 +81,10 @@ class DrawParticlesGL(object):
         
         self.__init_vect_fl = False
         
+        self.__log_indices = None
+        self.__log_array = None
+        
+        
     def __del__(self):
         if self.__sph_dl != None :
             glDeleteLists( self.__sph_dl , 1 )
@@ -176,38 +184,29 @@ class DrawParticlesGL(object):
     def draw_trajectory(self):
         
         if self.pset.log_size < self.trajectory_step + 1 :
-            return 
+            return
         
+        if self.__log_indices == None :
+            self.__log_indices = self.pset.get_log_indices_segments( True )
+            self.__log_array = np.zeros( ( self.pset.log_max_size , self.pset.dim ) )
+                 
         unit = self.pset.unit
         glLineWidth( 1.0 )
         
-        if self.trajectory_step <= 1 :
+        for i in range( self.pset.size ):
+            glColor4f( *self.__color_fun( self.pset , i ) )
             
-            for i in range( self.pset.size ) :
-                glColor4f( *self.__color_fun( self.pset , i ) )
-                glBegin(GL_LINE_STRIP)
-                for X in self.pset.logX :
-                    glVertex3f( X[i,0] / unit ,
-                                X[i,1] / unit ,
-                                X[i,2] / unit )
-
-                glEnd()        
-        else:
+            glEnableClientState(GL_VERTEX_ARRAY)
             
-            for i in range( self.pset.size ) :
-                glColor4f( *self.__color_fun( self.pset , i ) )
-                glBegin(GL_LINE_STRIP)
-                j = 0
-                for X in self.pset.logX :
-                    j += 1
-                    if ( j % self.trajectory_step ) == 0  :
-                        glVertex3f( X[i,0] / unit ,
-                                    X[i,1] / unit ,
-                                    X[i,2] / unit )
-    
-                glEnd()
-
+            ( b , e ) = self.pset.read_log_array( i , ( self.__log_array, ) )
     
+            glVertexPointer( 3 , GL_FLOAT , 0 , self.__log_array / unit )
+            
+            glDrawElements( GL_LINES , e-1 , GL_UNSIGNED_INT , self.__log_indices )
+            
+            glDisableClientState(GL_VERTEX_ARRAY)
+            
+                
     def get_pcolor(self):
         return 
     
@@ -283,7 +282,7 @@ class DrawParticlesGL(object):
         glDisableClientState(GL_VERTEX_ARRAY)
         
         if self.__vect_color_fun_fl :
-            glEnableClientState(GL_COLOR_ARRAY)
+            glDisableClientState(GL_COLOR_ARRAY)
         
     
     def draw(self):
