@@ -18,25 +18,31 @@
 import numpy as np
 from collections import deque
 
+import pyparticles.pset.logger as log
+
+import random
+import string
+
 class ParticlesSet(object):
     """
     The main class for storing the particles data set.
     
-        ============= =============== =======================================================
-        Arguments
-        ============= =============== =======================================================
-        size          (default 0)     Number of particles
-        dim           (default 3)     dimensions of the system 2 or 3 ... 2D 3D
-        mass          (dafault True)  if True the particles have a mass.
-        label         (default False) if true it's possible to set a name for each particle
-        velocity      (dafault True)  if true the particles has a velocity
-        charge        (default False) if true the particles have an electric charge.
-        log_X         (default False) if true it's possible to logging the position
-        log_V         (default False) if true it's possible to logging the velocity
-        log_max_size  (default 0) set the maximal size of the log queue
-        ============= =============== =======================================================
+    Constructor:
         
-       Note: The properties: position X and velocity V are mandatory.
+    :param    size:          (default 1)     Number of particles
+    :param    dim:           (default 3)     dimensions of the system 2 or 3 ... 2D 3D
+    :param    mass:          (dafault True)  if True the particles have a mass.
+    :param    label:         (default False) if true it's possible to set a name for each particle
+    :param    velocity:      (dafault True)  if true the particles has a velocity
+    :param    charge:        (default False) if true the particles have an electric charge.
+    :param    log_X:         (default False) if true it's possible to logging the position
+    :param    log_V:         (default False) if true it's possible to logging the velocity
+    :param    log_max_size:  (default 0)     set the maximal size of the log queue
+        
+
+    .. note:: 
+    
+        The properties: position X and velocity V are mandatory.
     """
     def __init__( self , size=1 , dim=3 , boundary=None ,
                  label=False , mass=True , velocity=True , charge=False ,
@@ -75,19 +81,9 @@ class ParticlesSet(object):
         
         self.__unit = 1.0
         self.__mass_unit = 1.0
-        
-        if log_X == True :
-            self.__log_X = deque([])
-        else :
-            self.__log_X = None
-            
-        if log_V == True :
-            self.__log_V = deque([])
-        else :
-            self.__log_V = None
-            
-        self.__log_max_size = log_max_size
-        self.__log_len = 0
+                
+        self.__log = dict()
+        self.__default_logger = None
         
         self.__property_dict = dict()
         self.__property_dict['X'] = self.__X
@@ -176,10 +172,13 @@ class ParticlesSet(object):
     def get_by_name( self , property_name ):
         """
         Return a property reference by name:
-        for example 'X' , 'V' , 'M' ...
+            for example 'X' , 'V' , 'M' , 'Q' ...
+        
+        :param property_name: The name of a property 
+        
         ::
         
-            # set to [1,2,3] the position of the 10th particle
+            # set to [1,2,3] the coordinates of the 10th particle
             pset.get_by_name('X')[10,:] = [1,2,3]
         """
         return self.__property_dict[property_name]
@@ -191,20 +190,18 @@ class ParticlesSet(object):
         
         If the model of the property is 'list' the dim is forced to 1
         
-            ===================  ==============================================================================
-            Arguments
-            ===================  ==============================================================================
-             property_name       the name of the new property
-             dim                 the dimension of the new property ( 2 = "2D  , 3 = 3D ... )
-             model               'list' or 'numpy_array'
-             to_type=np.float64  an array-numpy type for the model 'numpy_array' [ np.float64 , np.int64 ... ]
-            ===================  ==============================================================================
+        :param     property_name:       the name of the new property
+        :param     dim:                 the dimension of the new property ( 2 = "2D  , 3 = 3D ... )
+        :param     model:               'list' or 'numpy_array'
+        :param     to_type: [np.float64]  an array-numpy type for the model 'numpy_array' [ np.float64 , np.int64 ... ]
+            
             
         For example add 'friction' or 'radius':
         ::
         
             # Add the friction to the particles set 
             pset.add_property_by_name( "friction" , dim=1 , to_type=np.float32 )
+            pset.add_property_by_name( "radius" , dim=1 , to_type=np.float64 )
         """
         
         if dim == None :
@@ -218,9 +215,9 @@ class ParticlesSet(object):
 
     def get_properties_names(self):
         """
-        Return a list of containig the names of all properties
+        Return a list of containing the names of all properties
         """
-        return self.__property_dict.keys()
+        return self.__property_dict.keys().copy()
 
 
     def getX(self):
@@ -311,20 +308,20 @@ class ParticlesSet(object):
     
     def notify_set_changed(self):
         """
-        Call this methos when the particle set is modified.
+        Call this methods when the particle set is modified.
         """
         for e in self.__notify_set_changed :
             e.particles_set_changed( self )
 
     def add_set_changed_listener( self , listener ) :
         """
-        Add an object that contains a member methond called: *particles_set_changed( pset )* that there will be called if the particle set will be modified.
+        Add an object that contains a member methods called: *particles_set_changed( pset )* that there will be called if the particle set will be modified.
         """
         self.__notify_set_changed.append( listener )
 
     def update_boundary( self ):
         """
-        Update the particle set according to the boudary rule
+        Update the particle set according to the boundary rule
         """
         if self.__bound != None :
             self.__bound.boundary( self )
@@ -335,104 +332,113 @@ class ParticlesSet(object):
     def set_boundary( self , boundary):
         self.__bound = boundary
 
-    boundary = property( get_boundary , set_boundary , doc="return the reference to the boudary, None if the boudary are not set or open")
+    boundary = property( get_boundary , set_boundary , doc="return the reference to the boundary, None if the boundary are not set or open")
 
     
+
+      
+    def append_logger( self , logger , key=None ):
+        if key == None :
+            key = "".join(random.choice(string.ascii_uppercase + string.ascii_lowercase + string.digits) for x in range(40))
+            
+        self.__log[key] = logger
+        
+        if self.__default_logger == None :
+            self.__default_logger = key
+        
+        return key
+     
+     
+    def enable_log( self , log_X=True , log_V=False , sim_time=None , log_max_size=0 ):
+        """
+        Eanble the X and V logging:
+        
+        :param   log_X=True: log the positions
+        :param   log_V=False: log the velocity
+        :param   log_max_size: max size of the log queue
+        """
+        
+        if len( self.__log ) == 0 :
+            logg = log.Logger( self , log_max_size=log_max_size , log_X=log_X , log_V=log_V , sim_time=sim_time )
+            self.append_logger( logg )     
+        
+        
+    def log(self):
+        """
+        | If the log is enabled, save the current status in the log queue.
+        | The last element of the queue will be removed if we reach the max allowed size
+        """
+        for key in self.__log.keys() :
+            self.__log[key].log()
+    
+    def close_log(self):
+        """
+        This function must be called after the end of the simulation for closing the log procedure.
+        """
+        for key in self.__log.keys() :
+            self.__log[key].close_log()
+    
+    
     def get_log_max_size( self ):
-        return self.__log_max_size
+        return self.__log[self.__default_logger].log_max_size
     
     def set_log_max_size( self , log_max_size ):
-        self.__log_max_size = log_max_size
+        self.__log[self.__default_logger].log_max_size = log_max_size
     
     log_max_size = property( get_log_max_size , set_log_max_size , doc="set and get the max allowed size of the log")
+        
     
     
-    def enable_log( self , log_X=True , log_V=False , log_max_size=0 ):
-        """
-        |Eanble the X and V logging:
-        |args:
-            #. log_X=True : log the positions
-            #. log_V=False : log the velocity
-            #. log_max_size: max size of the log queue
-        """
-        if ( not self.log_X_enabled ) and log_X :
-            self.__log_X = deque([])
-            
-        if ( not self.log_V_enabled ) and log_V :
-            self.__log_V = deque([])
-            
-        self.log_max_size = log_max_size
+    def get_log_array( self , i , log_X=True , log_V=False ):
+        return self.__log[self.__default_logger].get_log_array( i , log_X , log_V )
+    
+    
+    def read_log_array( self , i , ta , log_X=True , log_V=False ):
+        return self.__log[self.__default_logger].read_log_array( i , ta , log_X , log_V )
+    
+    
+    def get_log_indices_segments( self , full=False ):
+        return self.__log[self.__default_logger].get_log_indices_segments( full )
+    
+    
+    def set_default_logger( self , key ):
+        
+        if key not in self.__log.keys() :
+            raise ValueError("A log named %s do not exits" % key )
+        
+        self.__default_logger = key
+        
             
     
     def get_log_size(self):
-        return self.__log_len
+        return self.__log[self.__default_logger].log_size
     
     log_size = property( get_log_size )
 
     def get_log_X_enabled(self):
-        return ( self.__log_X != None )
+        if not self.log_enabled :
+            return False
+        else :
+            return self.__log[self.__default_logger].log_X_enabled
     
     def get_log_V_enabled(self):
-        return ( self.__log_V != None )
+        if not self.log_enabled :
+            return False
+        else :        
+            return self.__log[self.__default_logger].log_V_enabled
 
     def get_log_enabled(self):
-        return ( self.log_V_enabled or self.log_X_enabled )
+        return len( self.__log ) > 0
 
     log_V_enabled = property( get_log_V_enabled , doc="return true if the logging of the position is enabled")
     log_X_enabled = property( get_log_X_enabled , doc="return true if the logging of the velocity is enabled")
     
     log_enabled = property( get_log_enabled , doc="return true if the logging of position or velocity is enabled")
 
-    
-
-    def log(self):
-        """
-        if the log is enabled, save the current status in the log queue.
-        
-        The last element of the queue will be removed if we reach the max allowed size
-        """
-        delta_x = 0
-        delta_v = 0
-        
-        if self.__log_X != None :
-            lX = np.zeros(( self.size , self.dim ))
-            lX[:] = self.X
             
-            #print(lX)
-            
-            if self.log_size > self.log_max_size :
-                self.__log_X.popleft()
-                delta_x -= 1
-            
-            self.__log_X.append( lX )
-            delta_x += 1
-        
-        if self.__log_V != None :
-            lV = np.zeros(( self.size , self.dim ))
-            lV[:] = self.V
-            
-            if self.log_size > self.log_max_size :
-                self.__log_V.popleft()
-                delta_v -= 1
-            
-            self.__log_V.append( lV )
-            delta_v+=1
-            
-        #print( self.__log_X )
-        self.__log_len += max( [ delta_x , delta_v ]  )
-        
     def jump( self , indx ):
         pass        
 
-    def get_logX( self ):
-        return self.__log_X
-        
-    def get_logV( self , i ):
-        return self.__log_V
-    
-    logX = property( get_logX , doc="return the log queue X: position" )
-    logV = property( get_logV , doc="return the log queue V: velocity" )
-    
 
     def set_unit( self , u ):
         self.__unit = u
@@ -440,7 +446,7 @@ class ParticlesSet(object):
     def get_unit(self):
         return self.__unit
     
-    unit = property( get_unit , set_unit , doc="set the unit lenght")
+    unit = property( get_unit , set_unit , doc="set the unit length")
     
     
     def set_mass_unit( self , u ):
@@ -453,10 +459,20 @@ class ParticlesSet(object):
     
     
     def update_centre_of_mass(self):
+        """
+        Compute and return the center of mass
+        """
         self.__centre_mass = np.sum( self.__X * self.__mass , axis=0 ) / np.float( self.__size )
         return self.__centre_mass
         
     def centre_of_mass(self):
+        """
+        Return the stored center of mass.
+        
+        .. note::
+        
+            this function don't compute the center of mass, but simply return the stored value.
+        """
         return self.__centre_mass
     
     def get_dim(self):
@@ -465,8 +481,9 @@ class ParticlesSet(object):
     def get_size( self ):
         return self.__size
     
-    dim = property( get_dim )
-    size = property( get_size )
+    dim = property( get_dim , doc="get the dim of the set" )
+    
+    size = property( get_size , doc="get the size of the set" )
     
     def add_clusters( self , Cs , n ):
         i = 0
