@@ -20,7 +20,7 @@
 # Current version
 v_major    = 0
 v_minor    = 3
-v_revision = 3
+v_revision = 4
 ###########################
 
 def py_particle_version():
@@ -29,3 +29,11 @@ def py_particle_version():
     global v_revision
     return "%d.%d.%d" % ( v_major , v_minor , v_revision )
 
+
+def test_pyopencl():
+    try :
+        import pyopencl
+    except :
+        return False
+    else :
+        return True
\ No newline at end of file
